/// <reference types="react" />
import * as React from 'react';
import { CalendarMonthProps } from './CalendarMonth';
export interface DateRange {
    startDate: Date;
    endDate: Date;
}
/**
 * @private
 */
export declare type PickedCalendarMonthProps = Pick<CalendarMonthProps, 'showDropdowns' | 'startDate' | 'endDate' | 'minDate' | 'maxDate'>;
export interface DateRangeControlRenderProps extends PickedCalendarMonthProps {
    onDayClick(date: Date): void;
    onDayHover(date: Date): void;
    months: Date[];
    moveForward(): void;
    moveBackward(): void;
}
export interface DateRangeControlProps extends PickedCalendarMonthProps {
    /**
     * Callback when start and/or end dates are changed
     *
     * @param {Object} dates
     * @param {Date} dates.startDate
     * @param {Date | undefined} dates.endDate
     */
    onDatesChange?(dates: DateRange): void;
    showThreeMonths?: boolean;
    render(props: DateRangeControlRenderProps): React.ReactNode;
}
/**
 * @private
 */
export interface DateRangeControlState {
    startDate?: Date;
    endDate?: Date;
    months: Date[];
    selectionActive: boolean;
}
export declare class DateRangeControl extends React.Component<DateRangeControlProps, DateRangeControlState> {
    private numOfMonths;
    constructor(props: DateRangeControlProps);
    componentWillReceiveProps(nextProps: DateRangeControlProps): void;
    handleDayClick: (day: Date) => void;
    handleDayHover: (day: Date) => void;
    handleNavigation: (months: number) => () => void;
    render(): React.ReactNode;
}
